@@ -5,9 +5,8 @@
 {
     msg <- styletext(styletext(paste("\nSemNetCleaner (version ", packageVersion("SemNetCleaner"), ")", sep = ""), defaults = "underline"), defaults = "bold")
     
-    msg <- paste(msg, '\nFor help getting started, see <https://doi.org/10.31234/osf.io/eht87> \n')
+    msg <- paste(msg, '\nFor help getting started, see <https://doi.org/10.1037/met0000463> \n')
     msg <- paste(msg,"For bugs and errors, submit an issue to <https://github.com/AlexChristensen/SemNetCleaner/issues>\n\n")
-    msg <- paste(msg, "WARNING: There have been major updates to the SemNetCleaner package.\n Please see 'Package NEWS' for a detailed list of updates (see 'Changes in version 1.2.0')\n", sep = "")
     
     packageStartupMessage(msg)
 }
\ No newline at end of file
